#include <stdio.h>
#include <string.h>

#define MAX 1024
#define infinity 999666111

int n, k, a[MAX], sum[MAX];
int g[MAX][MAX];
int f[MAX][MAX];
int best[MAX][MAX];
int bestX[MAX];
int answer;

void input(void)
{
	int i;
	//
	scanf("%d%d", &n, &k);
	for (i = 1; i <= n; i++)
		scanf("%d", &a[i]);
}

/*
 * Memoization-based approach to calculate the target function f(i, l)
 *
 * f(i, l) tells us the optimal value if we have to place `l' additional bus
 * stops, and the last placed bus stop is at position `i'.
 *
 * The function may be defined recursively:
 * f(i, l) := {
 *              g(i, n)                                                if l = 0
 *              MIN [ for j = i + 1 to n -1: f(j, l-1) + g(i, j) ]     if l > 0
 *            }
 */
 
int recursion(int i, int left)
{
	int j, temp, result;
	//
	if (0 == left)
		return g[i][n];
	if (i == n - 1)
		return 0;
	if (f[i][left] == -1) {
		result = infinity;
		for (j = i + 1; j < n; j++) {
			temp = g[i][j] + recursion(j, left - 1);
			if (temp < result) {
				result = temp;
				best[i][left] = j;
			}
			if (best[i+1][left-1] && j >= best[i+1][left-1]) break;
		}
		f[i][left] = result;
	}
	return f[i][left];
}

void solve(void)
{
	int i, j, l;
	/*
	 * precalculate the sums:
	 *   sum[i] := SUM[ for k = 1 to i: a[k] ]
	 */
	sum[0] = 0;
	for (i = 1; i <= n; i++)
		sum[i] = sum[i-1] + a[i];
	
	/*
	 * precalculate the function g(i,j)
	 * g(i,j) := SUM[ for k = i to j: a[k] * min(k-i, j-k) ]
	 *
	 * Could be defined recursively for faster calculation:
	 *
	 * g(i, j) := {
	 *             0,                                        if j - i < 2
	 *             g(i+1, j-1) + SUM a[i+1 .. j-1]           if j - i >= 2
	 *            }
	 */
	
	for (l = 1; l <= n; l++) {
		for (i = 1; i <= n - l + 1; i++) {
			j = i + l - 1;
			if (l < 3) 
				g[i][j] = 0;
			else
				g[i][j] = g[i+1][j-1] + sum[j-1] - sum[i];
		}
	}
	
	/*
	 * fill the memoization array with -1
	 */
	memset(f, 0xff, sizeof(f));
	
	/*
	 * calculate the function f
	 */
	answer = recursion(1, k - 2);
	
}

void output(void)
{
	printf("%d\n", answer);
	//
#ifdef SHOW
	printf("placed bus stops on positions:\n1");
	int i = 1, j = k - 2;
	while (j) {
		printf(" %d", best[i][j]);
		i = best[i][j];
		j--;
	}
	printf(" %d\n", n);
	printf("The answer acheived is %d\n", answer);
#endif
}

int main(void)
{
	input();
	solve();
	output();
	return 0;
}
